
## ----echo=FALSE----------------------------------------------------------
results = "hide"; echo = FALSE


## ----setup, include=FALSE, cache=FALSE-----------------------------------
library(knitr)
options(replace.assign=FALSE,width=50)

opts_chunk$set(fig.path='knitr_figure/graphics-', 
               cache.path='knitr_cache/graphics-', 
               fig.align='center', 
               dev='pdf', fig.width=5, fig.height=5, 
               fig.show='hold', cache=FALSE, par=TRUE)
knit_hooks$set(crop=hook_pdfcrop)

knit_hooks$set(par=function(before, options, envir){
    if (before && options$fig.show!='none') {
        par(mar=c(3,3,2,1),cex.lab=.95,cex.axis=.9,
            mgp=c(2,.7,0),tcl=-.01, las=1)
}}, crop=hook_pdfcrop)


## ------------------------------------------------------------------------
x = 5


## ----eval=FALSE, tidy=FALSE----------------------------------------------
## install.packages("nclRintroduction",
##                  repos="http://R-Forge.R-project.org")


## ----eval=FALSE, tidy=FALSE----------------------------------------------
## install.packages("nclRintroduction",
##                  repos="http://R-Forge.R-project.org",
##                  type="source")


## ------------------------------------------------------------------------
library("nclRintroduction")


## ------------------------------------------------------------------------
library(nclRintroduction)
data(movies)
d = movies


## ----results="hide"------------------------------------------------------
## d is a data frame
colnames(d)


## ------------------------------------------------------------------------
colnames(d)[17]
colnames(d)[17] = "MPAA"


## ----results="hide"------------------------------------------------------
d$Year


## ----results="hide"------------------------------------------------------
d[,2]


## ------------------------------------------------------------------------
head(d$Title, 5)


## ----echo=echo, results=results------------------------------------------
##5 specifies the number of rows to return
## For example, using 2 gives
head(d$Title, 2)


## ----echo=echo, results=results------------------------------------------
## tail gives the *last* few values/rows


## ----F1, fig.keep='none'-------------------------------------------------
plot(d$Length, d$Rating)


## ----ref.label='F1', dev='pdf', out.width='\\textwidth', echo=FALSE------


## ----F2, fig.keep='none'-------------------------------------------------
plot(d$Length, d$Rating, xlab="Length", ylab="Rating")


## ----ref.label='F2', dev='pdf', out.width='\\textwidth', echo=FALSE------


## ----fig.keep='none', tidy=FALSE, echo=echo------------------------------
plot(d$Length, d$Rating, 
     xlab="Length", ylab="Rating", 
     ylim=c(1, 10))


## ----fig.keep='none', tidy=FALSE, echo=echo------------------------------
plot(d$Length, d$Rating, 
     xlab="Length", ylab="Rating", 
     ylim=c(1, 10), col=2)
##Or
plot(d$Length, d$Rating, 
     xlab="Length", ylab="Rating", 
     ylim=c(1, 10), col="red")


## ----fig.keep='none', tidy=FALSE, echo=echo------------------------------
plot(d$Length, d$Rating, 
     xlab="Length", ylab="Rating", 
     ylim=c(1, 10), col=2, 
     main="Movie rating against length")


## ----tidy=FALSE----------------------------------------------------------
op = par(mar=c(3,3,2,1), mgp=c(2,.7,0), 
         tck=-.01, las=1)


## ----tidy=FALSE, echo=echo-----------------------------------------------
#  * mar: A numerical vector of the form c(bottom, left, top, right) 
# which gives the number of lines of margin to be specified on the four 
# sides of the plot. The default is c(5, 4, 4, 2) + 0.1
# 
#  * mgp: The margin line for the axis title, axis labels and axis line. 
# The first number affects title,  whereas the second and third values affect 
# axis. The default is c(3, 1, 0).
# 
#  * tck: Reduces the tick length.
# 
#  * las: Changes the style the axis labels. las=1 rotates the y-axis label by 90 degrees.


## ------------------------------------------------------------------------
par(op)


## ----echo=echo, results=results------------------------------------------
##Mean
mean(d$Length)
##Mean
median(d$Length)
##Mean
sd(d$Length)


## ----F3, fig.keep='none'-------------------------------------------------
hist(d$Year)


## ----ref.label='F3', dev='pdf', out.width='\\textwidth', echo=FALSE------


## ----F4, fig.keep='none'-------------------------------------------------
hist(d$Year, breaks="FD")


## ----F5, fig.keep='none'-------------------------------------------------
boxplot(d$Rating)


## ----ref.label='F5', dev='pdf', out.width='\\textwidth', echo=FALSE------


## ----fig.keep='none'-----------------------------------------------------
boxplot(d$Rating ~ d$Romance)


## ----fig.keep='none', echo=echo------------------------------------------
##Conditioning on other variables
boxplot(d$Rating ~ d$Romance + d$Action)


## ----F6, fig.keep='none', echo=echo--------------------------------------
## Change axis labels
## Plot a boxplot but skip the labels
boxplot(d$Rating ~ d$Romance, axes=FALSE, frame.plot=TRUE,
        ylim=c(0,10))
## Y-axis. 0 to 10 in steps of 2.5
axis(2,at=seq(0,10,2.5))
## X-Axis, at points x=1 & x=2, 
## but with labels "non R" and "Romantic"
axis(1,at=1:2, labels=c("Non R", "Romantic") )


## ------------------------------------------------------------------------
(op = par(cex.lab=0.9))


## ------------------------------------------------------------------------
op


## ------------------------------------------------------------------------
par(op)


## ----eval=FALSE----------------------------------------------------------
## library(nclRintroduction)
## vignette("solutions1", package="nclRintroduction")


